<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_Faq
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.Pinpoint.co.uk)
 * @author      Ahmed Goda <hello@Pinpoint.co.uk>
 */

namespace Pinpoint\Faq\Block\Adminhtml\Faq\Edit;

use Magento\Backend\Block\Widget\Context;
use Magento\Framework\Exception\NoSuchEntityException;
use Pinpoint\Faq\Api\Data\FaqInterface;
use Pinpoint\Faq\Api\FaqRepositoryInterface;

/**
 * Class GenericButton
 */
class GenericButton
{
    /**
     * @var Context
     */
    protected $context;

    /**
     * @var FaqRepositoryInterface
     */
    protected $faqRepository;

    /**
     * @param Context $context
     * @param FaqRepositoryInterface $faqRepository
     */
    public function __construct(
        Context $context,
        FaqRepositoryInterface $faqRepository
    ) {
        $this->context = $context;
        $this->faqRepository = $faqRepository;
    }

    /**
     * Return the id of the selected item
     *
     * @return int|null
     */
    public function getItemId(): ?int
    {
        try {
            $faq = $this->faqRepository->getById(
                $this->context->getRequest()->getParam(FaqInterface::FAQ_ID, 0)
            );
            if ($faq instanceof FaqInterface) {
                return $faq->getId();
            }
        } catch (NoSuchEntityException $e) {
        }
        return null;
    }

    /**
     * Generate url by route and parameters
     *
     * @param  string $route
     * @param  array  $params
     * @return string
     */
    public function getUrl($route = '', $params = []): string
    {
        return $this->context->getUrlBuilder()->getUrl($route, $params);
    }
}