<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_Faq
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.Pinpoint.co.uk)
 * @author      Ahmed Goda <hello@Pinpoint.co.uk>
 */

namespace Pinpoint\Faq\Controller\Adminhtml\Faq;

use Magento\Backend\App\Action\Context;
use Magento\Framework\App\Action\HttpPostActionInterface;
use Magento\Framework\Registry;
use Pinpoint\Faq\Api\Data\FaqInterface;
use Pinpoint\Faq\Api\FaqRepositoryInterface;
use Pinpoint\Faq\Controller\Adminhtml\Faq;
use Pinpoint\Faq\Model\ResourceModel\FaqFactory as FaqResourceFactory;

/**
 * Class Delete
 */
class Delete extends Faq implements HttpPostActionInterface
{
    /**
     * @var FaqResourceFactory
     */
    protected $faqResourceFactory;

    /**
     * @var FaqRepositoryInterface
     */
    protected $faqRepository;

    /**
     * @param Context $context
     * @param Registry $coreRegistry
     * @param FaqRepositoryInterface $faqRepository
     * @param FaqResourceFactory $faqResourceFactory
     */
    public function __construct(
        Context $context,
        Registry $coreRegistry,
        FaqResourceFactory $faqResourceFactory,
        FaqRepositoryInterface $faqRepository
    ) {
        parent::__construct($context, $coreRegistry);
        $this->faqResourceFactory = $faqResourceFactory;
        $this->faqRepository = $faqRepository;
    }

    /**
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        $id = $this->getRequest()->getParam(FaqInterface::FAQ_ID);
        if ($id) {
            try {
                $faqResource = $this->faqResourceFactory->create();
                // init model and delete
                $model = $this->faqRepository->getById($id);
                $faqResource->delete($model);
                $this->messageManager->addSuccessMessage(__('You deleted the FAQ.'));
                return $resultRedirect->setPath('*/*/');
            } catch (\Exception $e) {
                $this->messageManager->addErrorMessage($e->getMessage());
                return $resultRedirect->setPath('*/*/edit', [FaqInterface::FAQ_ID => $id]);
            }
        }
        $this->messageManager->addErrorMessage(__('We can\'t find a question to delete.'));
        return $resultRedirect->setPath('*/*/');
    }
}
