<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_Faq
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.Pinpoint.co.uk)
 * @author      Ahmed Goda <hello@Pinpoint.co.uk>
 */

namespace Pinpoint\Faq\Model;

use Magento\Framework\Model\AbstractModel;
use Pinpoint\Faq\Api\Data\FaqInterface;
use Pinpoint\Faq\Model\ResourceModel\Faq as FaqResource;

/**
 * Class Faq
 */
class Faq extends AbstractModel implements FaqInterface
{
    protected $_idFieldName = FaqInterface::FAQ_ID;

    /**
     * Faq initialisation
     */
    protected function _construct()
    {
        $this->_init(FaqResource::class);
    }

    /**
     * @return string
     */
    public function getCustomerName(): string
    {
        return $this->getData(FaqInterface::CUSTOMER_NAME);
    }

    /**
     * @param string $customerName
     * @return FaqInterface
     */
    public function setCustomerName(string $customerName): FaqInterface
    {
        return $this->setData(FaqInterface::CUSTOMER_NAME);
    }

    /**
     * @return string
     */
    public function getCustomerEmail(): string
    {
        return $this->getData(FaqInterface::CUSTOMER_EMAIL);
    }

    /**
     * @param string $customerEmail
     * @return FaqInterface
     */
    public function setCustomerEmail(string $customerEmail): FaqInterface
    {
        return $this->setData(FaqInterface::CUSTOMER_EMAIL);
    }

    /**
     * @return string
     */
    public function getQuestionText(): string
    {
        return $this->getData(FaqInterface::QUESTION_TEXT);
    }

    /**
     * @param string $text
     * @return FaqInterface
     */
    public function setQuestionText(string $text): FaqInterface
    {
        return $this->setData(FaqInterface::QUESTION_TEXT);
    }

    /**
     * @return string
     */
    public function getAnswerText(): string
    {
        return $this->getData(FaqInterface::ANSWER_TEXT);
    }

    /**
     * @param string $text
     * @return FaqInterface
     */
    public function setAnswerText(string $text): FaqInterface
    {
        return $this->setData(FaqInterface::ANSWER_TEXT);
    }

    /**
     * @return bool
     */
    public function isActive(): bool
    {
        return $this->getData(FaqInterface::IS_ACTIVE);
    }

    /**
     * @return FaqInterface
     */
    public function setActive(): FaqInterface
    {
        return $this->setData(FaqInterface::IS_ACTIVE, true);
    }

    /**
     * @return FaqInterface
     */
    public function setInactive(): FaqInterface
    {
        return $this->setData(FaqInterface::IS_ACTIVE, false);
    }

    /**
     * @return int|null
     */
    public function getProductId()
    {
        return $this->getData(FaqInterface::PRODUCT_ID);
    }

    /**
     * @return FaqInterface
     */
    public function setProductId(): FaqInterface
    {
        return $this->setData(FaqInterface::PRODUCT_ID, false);
    }

    /**
     * @return string
     */
    public function getCreatedAt(): string
    {
        return $this->getData(FaqInterface::CREATED_AT);
    }

    /**
     * @param \DateTime $dateTime
     * @return FaqInterface
     */
    public function setCreatedAt(\DateTime $dateTime): FaqInterface
    {
        return $this->setData(FaqInterface::CREATED_AT, $dateTime);
    }

    /**
     * @return string
     */
    public function getUpdatedAt(): string
    {
        return $this->getData(FaqInterface::UPDATED_AT);
    }

    /**
     * @param \DateTime $dateTime
     * @return FaqInterface
     */
    public function setUpdatedAt(\DateTime $dateTime): FaqInterface
    {
        return $this->setData(FaqInterface::UPDATED_AT, $dateTime);
    }

    /**
     * @return int|null
     */
    public function getStoreId()
    {
        return $this->getData(FaqInterface::STORE_ID);
    }

    /**
     * @return FaqInterface
     */
    public function setStoreId(): FaqInterface
    {
        return $this->setData(FaqInterface::STORE_ID, false);
    }
}
