<?php
/**
 * @category  Pinpoint
 * @package   Pinpoint_Faq
 * @copyright Copyright (c) 2019 Pinpoint Designs. (http://www.Pinpoint.co.uk)
 * @author    Ahmed Goda <hello@Pinpoint.co.uk>
 */

namespace Pinpoint\Faq\Setup;

use Magento\Catalog\Model\Product;
use Magento\Eav\Model\Entity\Attribute\Backend\ArrayBackend as Backend;
use Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface;
use Magento\Eav\Setup\EavSetupFactory;
use Magento\Framework\Setup\InstallDataInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Pinpoint\Faq\Model\Attribute\Source\Faqs as Source;

/**
 * Class InstallData
 */
class InstallData implements InstallDataInterface
{
    /**
     * @var EavSetupFactory
     */
    protected $eavSetupFactory;

    /**
     * @param EavSetupFactory $eavSetupFactory
     */
    public function __construct(EavSetupFactory $eavSetupFactory)
    {
        $this->eavSetupFactory = $eavSetupFactory;
    }

    /**
     * Installs data for a module
     *
     * @param ModuleDataSetupInterface $setup
     * @param ModuleContextInterface $context
     * @return void
     */
    public function install(ModuleDataSetupInterface $setup, ModuleContextInterface $context)
    {
        $eavSetup = $this->eavSetupFactory->create();
        $eavSetup->addAttribute(
            Product::ENTITY,
            'faqs',
            [
                'group' => 'Frequently Asked Questions',
                'type' => 'varchar',
                'label' => 'Questions',
                'input' => 'multiselect',
                'source' => Source::class,
                'backend' => Backend::class,
                'apply_to' => 'simple',
                'required' => false,
                'sort_order' => 910,
                'global' => ScopedAttributeInterface::SCOPE_STORE,
            ]
        );
    }
}
